.. KM3Astro documentation master file

.. include:: ../README.rst

.. toctree::
    :hidden:
    :titlesonly:

    self

.. toctree::
    :maxdepth: 2

    coordinates
    examples
    contribute
    changelog
    api

    Code Coverage <https://km3py.pages.km3net.de/km3astro/coverage>
    Source (Git) <https://git.km3net.de/km3py/km3astro.git>

* :ref:`genindex`
